﻿Type=Class
Version=2.00
@EndOfDesignText@
'Class module myInput
Sub Class_Globals
	Private pnl As Panel
	Private lTitle As Label
	Private aceInput As AutoCompleteEditText 
	Private bOk As Button 
	Private bCancel As Button 
	Private m_meobj As Object 
	Private m_act As Activity
	Private IME As IME
	Private m_ReturnFromInput As String
	Private m_NotInList As String
	Private m_AceMap As Map : m_AceMap.Initialize  
	
	Public input As String
	Public Response As Int 
	Public Title As String 
	
	Public INPUT_TYPE_NONE As Int : INPUT_TYPE_NONE = 0
	Public INPUT_TYPE_TEXT As Int : INPUT_TYPE_TEXT = 1
	Public INPUT_TYPE_DECIMAL_NUMBERS As Int : INPUT_TYPE_DECIMAL_NUMBERS = 12290
	Public INPUT_TYPE_NUMBERS As Int : INPUT_TYPE_NUMBERS = 2
	Public INPUT_TYPE_PHONE As Int : INPUT_TYPE_PHONE = 3
End Sub

'meObjIn is the Me keyword
'act Is the calling Activity
'returnfrominput Is the name of the Sub that handles the call back when the user has clicked Ok.
'notinlist is the name of the sub that will receive the NotInList notification. Set it to "" to disable it
'or don't create the sub in your calling activity
'
'Example: <code>Dim inp As myInput
'inp.Initialize(Me, Activity, "ReturnSub", "")</code>
'inp.setInputType(inp.INPUT_TYPE_DECIMAL_NUMBERS)
'inp.Show("Enter a price")
Sub Initialize(meObjIn As Object, act As activity, returnfrominput As String, notinlist As String)
	m_meobj = meObjIn
	m_act = act
	m_ReturnFromInput = returnfrominput
	m_NotInList = notinlist
	
	IME.Initialize("")
	
	pnl.Initialize("pnl")
	lTitle.Initialize("lTitle")
	aceInput.Initialize("aceInput")
	bOk.Initialize("bOk")
	bCancel.Initialize("bCancel")

	Response = DialogResponse.CANCEL
	
	pnl.Tag = "CUSTOMINPUT"
	pnl.Color = Colors.Gray
	pnl.Visible = False
	
	lTitle.Text = Title
	lTitle.Gravity = Gravity.CENTER_HORIZONTAL
	lTitle.Typeface = Typeface.DEFAULT_BOLD
	lTitle.TextSize = 22
	lTitle.TextColor = Colors.Blue
	
	aceInput.TextSize = 18
	aceInput.Typeface = Typeface.DEFAULT_BOLD
	aceInput.Text = input
	
	bOk.Text = "Ok"
	bOk.TextSize = 18
	bOk.Typeface = Typeface.DEFAULT_BOLD
	
	bCancel.Text = "Cancel"
	bCancel.TextSize = 18
	bCancel.Typeface = Typeface.DEFAULT_BOLD

	pnl.AddView(lTitle, 0dip, 0dip, 100%x, 40dip)
	pnl.AddView(aceInput, 0dip, 40dip, 320dip, 60dip)
	pnl.AddView(bOk, 0dip, 150dip, 120dip, 60dip)
	pnl.AddView(bCancel, 160dip, 150dip, 120dip, 60dip)
	m_act.AddView(pnl, 0, 0, 100%x, 100%y)
End Sub

'Show the dialog
'titlein is the Title you want to show
'
'Example: <code>inp.Show("Enter a Number")</code>
Public Sub Show(titlein As String)
	lTitle.Text = titlein
	Dim pnlExists As Boolean : pnlExists = False
	
	For I=0 To m_act.NumberOfViews-1
		Dim v As View
		v = m_act.GetView(I)
		
		If v Is Panel Then
			If v.Tag="CUSTOMINPUT" Then
				pnlExists = True 
				Exit
			End If
		End If
	Next
	If Not(pnlExists) Then m_act.AddView(pnl, 0, 0, 480, 600)
	
	aceInput.Text = input
	pnl.Visible = True
	IME.ShowKeyboard(aceInput) 
End Sub

'As the name suggests this hides the dialog.
'It actually removes it from the calling activity.
'The Show method above will re-create it as needed
Public Sub Hide
	'remove the panel from the activity
	For I=0 To m_act.NumberOfViews-1
		Dim v As View 
		
		v = m_act.GetView(I)
		
		If v Is Panel Then
			pnl = v
			
			If pnl.Tag="CUSTOMINPUT" Then
				pnl.RemoveView
				Exit
			End If
		End If
	Next
End Sub

'Set the INPUT TYPE of the AutoCompleteEditText
'
'Example: <code>inp.setInputType(inp.INPUT_TYPE_TEXT)</code>
Public Sub setInputType(inputtype As Int)
	aceInput.inputtype = inputtype
End Sub

'These set subs allow you to overwrite the preset settings for the Title that are applied in Initialize

'Change the text color of the Title
'Example: <code>inp.setTitleTextColor(Colors.Red)</code>
Public Sub setTitleTextColor(colorin As Int)
	lTitle.TextColor = colorin
End Sub

'Change the Text Size of the Title
'Example: <code>inp.setTitleTextSize(22)</code>
Public Sub setTitleTextSize(textsizein As Int)
	lTitle.TextSize = textsizein
End Sub

'Change the Gravity for the Title
'By Default it's centered
'Example: <code>inp.setTitleGravity(Gravity.LEFT)</code>
Public Sub setTitleGravity(gravityin As Int)
	lTitle.Gravity = gravityin
End Sub

'Set the AutoCompleteEditText's List
'Example: <code>inp.setItemsList(Array As Object("Work", "Home", School"))</code>
Public Sub setItemsList(Listin As List)
	m_AceMap.Clear 
	For I=0 To Listin.Size-1
		m_AceMap.Put(Listin.Get(I), Listin.Get(I))
	Next
	
	aceInput.SetItems(Listin)
End Sub

'Private subs to handle button clicks & the focuschanged event for the AutoCompleteEditText
'also the Click event for the AutoCompleteEditText

Private Sub bOk_Click
	IME.HideKeyboard 
	input = aceInput.Text 
	Response = DialogResponse.POSITIVE 
	Hide
	
	'let's see if we can fire the notinlist sub
	If SubExists(m_meobj, m_NotInList) Then
		If Not(m_AceMap.ContainsKey(aceInput.Text)) Then
			CallSub2(m_meobj, m_NotInList, aceInput.Text)
		End If
	End If
	
	'now see if we can fire the returnfrominput sub
	If SubExists(m_meobj, m_ReturnFromInput) Then
		CallSub3(m_meobj, m_ReturnFromInput, Response, input) 
	End If
End Sub

Private Sub bCancel_Click
	IME.HideKeyboard 
	input = Null
	Response = DialogResponse.CANCEL
	Hide
	
	If SubExists(m_meobj, m_ReturnFromInput) Then
		CallSub3(m_meobj, m_ReturnFromInput, Response, input) 
	End If
End Sub

Private Sub aceInput_FocusChanged(HasFocus As Boolean)
	If HasFocus=False Then
		IME.HideKeyboard
	Else
		If aceInput.Text<>"" Then
			IME.ShowKeyboard(aceInput)
			aceInput.SelectAll
		End If
	End If
End Sub

Private Sub aceInput_ItemClick (Value As String)
	bOk_Click
End Sub